.. _readme:


Curator
=======

Have indices in Elasticsearch? This is the tool for you!

Like a museum curator manages the exhibits and collections on display,
Elasticsearch Curator helps you curate, or manage your indices.

ANNOUNCEMENT
------------

Curator is breaking into version dependent releases. Curator 6.x will work with
Elasticsearch 6.x, Curator 7.x will work with Elasticsearch 7.x, and when it is
released, Curator 8.x will work with Elasticsearch 8.x.

Watch this space for updates when that is coming.